@@ -1,6 +1,6 @@
 package Text::Split;
 BEGIN {
-  $Text::Split::VERSION = '0.0011';
+  $Text::Split::VERSION = '0.0012';
 }
 # ABSTRACT: Text splitting with fine-grained control
 
@@ -15,7 +15,7 @@ has found => qw/ is ro required 1 isa Str /, default => '';
 has content => qw/ is ro required 1 isa Str /, default => '';
 has _matched => qw/ init_arg matched is ro isa ArrayRef /, default => sub { [] };
 sub matched { return @{ $_[0]->matched } }
-has matcher => qw/ is ro required 1 /, default => undef;
+has matcher => qw/ is ro /, default => undef;
 
 has default => qw/  is ro lazy_build 1 isa HashRef /;
 sub _build_default { {
@@ -25,7 +25,11 @@ sub _build_default { {
 sub BUILD {
     my $self = shift;
     my $data = $self->data;
-    $self->_data( \$data ) unless ref $data eq 'SCALAR';
+    if ( ref $data ne 'SCALAR' ) {
+        chomp $data;
+        $data .= "\n" if length $data;
+        $self->_data( \$data );
+    }
 }
 
 sub _fhead ($$) {
@@ -53,21 +57,23 @@ sub is_root {
     return ! $self->_parent;
 }
 
-sub _chomped2chomp ($) {
+sub _strip_edness ($) {
     my $slurp = $_[0];
     $slurp->{chomp} = delete $slurp->{chomped} if
         exists $slurp->{chomped} && not exists $slurp->{chomp};
+    $slurp->{trim} = delete $slurp->{trimmed} if
+        exists $slurp->{trimmed} && not exists $slurp->{trim};
 }
 
 sub _parse_slurp ($@) {
     my $slurp = shift;
     my %slurp = @_; # Can/will be overidden
 
-    _chomped2chomp \%slurp;
+    _strip_edness \%slurp;
 
     if ( ref $slurp eq 'HASH' ) {
         $slurp = { %$slurp };
-        _chomped2chomp $slurp;
+        _strip_edness $slurp;
         %slurp = ( %slurp, %$slurp );
     }
     else {
@@ -99,9 +105,10 @@ sub split {
     my %given = @_;
 
     my $data = $self->data;
-    my $from = $self->_parent ? $self->tail + 1 : 0;
     my $length = length $$data;
+    return unless $length; # Nothing to split
 
+    my $from = $self->_parent ? $self->tail + 1 : 0;
     return if $length <= $from; # Was already at end of data
 
     pos $data = $from;
@@ -139,9 +146,9 @@ sub slurp {
 
     my $split = $self;
 
-    _chomped2chomp \%given;
+    _strip_edness \%given;
     my %slurp = _parse_slurp $self->default->{slurp};
-    $slurp{chomp} = $given{chomp} if exists $given{chomp};
+    exists $given{$_} and $slurp{$_} = $given{$_} for qw/ chomp trim /;
     %slurp = _parse_slurp $slurp, %slurp unless $slurp eq 1;
 
     my @content;
@@ -149,13 +156,18 @@ sub slurp {
     push @content, $split->preceding;
     push @content, $split->content if $slurp{slurpr};
 
+    my $content = join '', @content;
+    if ( $slurp{trim} ) {
+        s/^\s*//, s/\s*$//, for $content;
+    }
+
     if ( wantarray && $slurp{wantlist} ) {
-        @content = grep { $_ ne "\n" } split m/(\n)/, join '', @content;
+        @content = grep { $_ ne "\n" } split m/(\n)/, $content;
         @content = map { "$_\n" } @content unless $slurp{chomp};
         return @content;
     }
     else {
-        return join '', @content;
+        return $content;
     }
 }
 
@@ -211,7 +223,7 @@ Text::Split - Text splitting with fine-grained control
 
 =head1 VERSION
 
-version 0.0011
+version 0.0012
 
 =head1 SYNOPSIS
 
